summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/dialogs/kgamedialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/dialogs/kgamedialog.h')
-rw-r--r--libkdegames/kgame/dialogs/kgamedialog.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/libkdegames/kgame/dialogs/kgamedialog.h b/libkdegames/kgame/dialogs/kgamedialog.h
index f7a0c6e5..f3256d8a 100644
--- a/libkdegames/kgame/dialogs/kgamedialog.h
+++ b/libkdegames/kgame/dialogs/kgamedialog.h
@@ -97,8 +97,8 @@ public:
* @param parent The parent of the dialog
* @param modal Whether the dialog is modal or not
**/
- KGameDialog(KGame* g, KPlayer* owner, const QString& title,
- QWidget* parent, bool modal = false);
+ KGameDialog(KGame* g, KPlayer* owner, const TQString& title,
+ TQWidget* parent, bool modal = false);
/**
* Create a KGameDialog with the standard configuration widgets. This
@@ -129,8 +129,8 @@ public:
* @param chatMsgId The ID of Chat messages. See KGameChat. Unused
* if initConfigs = false
**/
- KGameDialog(KGame* g, KPlayer* owner, const QString& title,
- QWidget* parent, long initConfigs = AllConfig,
+ KGameDialog(KGame* g, KPlayer* owner, const TQString& title,
+ TQWidget* parent, long initConfigs = AllConfig,
int chatMsgId = 15432, bool modal = false);
virtual ~KGameDialog();
@@ -175,7 +175,7 @@ public:
* already added config widget. Note that the game page will be used
* if parent is 0.
**/
- void addChatWidget(KGameDialogChatConfig* chat, QVBox* parent = 0);
+ void addChatWidget(KGameDialogChatConfig* chat, TQVBox* parent = 0);
/**
* Add a connection list to the dialog. The list consists of a
@@ -189,7 +189,7 @@ public:
* @param parent The parent of the widget. If 0 the networkConfig
* page is used.
**/
- void addConnectionList(KGameDialogConnectionConfig* c, QVBox* parent = 0);
+ void addConnectionList(KGameDialogConnectionConfig* c, TQVBox* parent = 0);
/**
* Add a new page to the dialog. The page will contain you new config
@@ -201,13 +201,13 @@ public:
* @param title The title of the newly added page.
* @return The newly added page which contains your config widget.
**/
- QVBox* addConfigPage(KGameDialogConfig* widget, const QString& title);
+ TQVBox* addConfigPage(KGameDialogConfig* widget, const TQString& title);
/**
* @return The QVBox of the given key, The key is from ConfigOptions
* Note that not all are supported yet
**/
- QVBox *configPage(ConfigOptions which);
+ TQVBox *configPage(ConfigOptions which);
/**
* @return The default netowrk config. Note that this always returns 0 if
@@ -227,7 +227,7 @@ public:
* it to the same page. Just use the returned page of
* addConfigPage.
**/
- void addConfigWidget(KGameDialogConfig* widget, QWidget* parent);
+ void addConfigWidget(KGameDialogConfig* widget, TQWidget* parent);
/**
* Used to add the main network config widget in a new page. Use this to
@@ -275,7 +275,7 @@ protected:
protected slots:
/**
* Called when the user clicks on Ok. Calls slotApply and
- * QDialog::accept()
+ * TQDialog::accept()
**/
virtual void slotOk();
@@ -306,9 +306,9 @@ protected slots:
/**
* Remove a config widget from the widget list.
- * @see QObject::destroyed
+ * @see TQObject::destroyed
**/
- void slotRemoveConfigWidget(QObject* configWidget);
+ void slotRemoveConfigWidget(TQObject* configWidget);
private:
void init(KGame*, KPlayer*);
@@ -201,13 +201,13 @@ public:
/**
- * @return The QVBox of the given key, The key is from ConfigOptions
+ * @return The TQVBox of the given key, The key is from ConfigOptions
* Note that not all are supported yet
**/